#Macrophyte ER Dimension Reduction and GLMs
#Meredith Brehob
#5/10/2022
#This code will reduce the number of covariates that I will input into my macrophyte ER model and will run glms on macrophyte ER data.

#Load packages
library(dplyr)
library(plyr)
library(lme4)
library(AICcmodavg)


#Read in data
df<-read.csv("Data_Final/Environmental_and_CompartmentMetabolism_AllObservations.csv")
plantdf<-subset(df, Substrate=="Plant")


##### Correlations with ER #####
sub <- plantdf %>% dplyr::select(Canal, Biomass_per_Area:Sed.pH, CR.mg.per.g.per.hr)#Subset to just site and variable data
crcor <- ldply(apply(sub[,-1], 2, function(z) cor(x = z, y = sub$CR.mg.per.g.per.hr, use = "complete.obs", method="kendall")), data.frame) #Create dataframe of correlations with biomass per area
colnames(crcor)<-c("Variable","Correlation") #Re-name columns

crp <- ldply(apply(sub[,-1], 2, function(z) cor.test(x = z, y = sub$CR.mg.per.g.per.hr, use = "complete.obs", method="kendall",exact=F)$p.value), data.frame) #Create dataframe of p-values from above correlations


##### Subset covariates #####
#Remove variables based on correlation coefficients and whether I have hypotheses
CRdf = subset(plantdf, select = -c(Biomass_per_Area, TSS.mgmL, Ext.Coeff, AQI.30da, PAR.30da, o.Phosphate.ug.L.PW, Nitrite.ppb.PW, Bromide.ppb.PW, TDC.mg.L.PW, DOC.mg.L.PW, TDN.ug.L.PW, Nitrite.ppb.SW, Nitrate.ppb.SW, Sed.Bulk.Density.g.mL., Sed.PercentOM, Sed.pH) )


##### Correlation among variables #####
## For variables without NAs:
mat <-as.matrix(CRdf[,8:22])#Matrix of covariates
matnoNA <- mat[ , colSums(is.na(mat)) == 0]#Matrix of covariates without NAs
cor_matrix <- cor(matnoNA, method="kendall")#Correlation matrix

##Run separately for variables with NAs:
#Porewater nitrate 
NO3PW <- ldply(apply(CRdf[,8:22], 2, function(z) cor(x = z, y = CRdf$Nitrate.ppb.PW, use = "complete.obs", method="kendall")), data.frame)

#Surface water phos 
PhosSW <- ldply(apply(CRdf[,8:22], 2, function(z) cor(x = z, y = CRdf$o.Phosphate.ug.L.SW, use = "complete.obs", method="kendall")), data.frame)

#Surface water ammonium
NH4SW <- ldply(apply(CRdf[,8:22], 2, function(z) cor(x = z, y = CRdf$Ammonium.mg.L.SW, use = "complete.obs", method="kendall")), data.frame)

#Surface water bromide
BrSW <- ldply(apply(CRdf[,8:22], 2, function(z) cor(x = z, y = CRdf$Bromide.ppb.SW, use = "complete.obs", method="kendall")), data.frame)


## Subset covariates
#Remove variables based on correlations with each other
CRdf = subset(CRdf, select = -c(PM.30da, SpC.uS.cm., Fluoride.ppb.PW, Nitrate.ppb.PW, o.Phosphate.ug.L.SW, Ammonium.mg.L.SW, Fluoride.ppb.SW, TDC.mg.L.SW, TDN.ug.L.SW))


##### Data organization for model input #####
#Make new variable with small value added to remove zeros
CRdf$CR0.0001<-CRdf$CR.mg.per.g.per.hr+0.0001

## Center data
df_sub <- select(CRdf, pH:Flow.cms.30da)
df_sub <- apply(df_sub, 2, function(x) (x - mean(x, na.rm=TRUE))/sd(x, na.rm=TRUE))

newdf <- cbind(CRdf[,c("Canal","Event","CR0.0001")], df_sub)

#Make event and canal factors
newdf$Event<-as.factor(newdf$Event)
newdf$Canal<-as.factor(newdf$Canal)

##### 0. Just Canal and Event #####
model0 <- glm(CR0.0001~Canal+Event-1,data=newdf,family=Gamma(link="log"))
summary(model0)
plot_model(model0)
plot(newdf$Canal,newdf$CR0.0001)
plot(newdf$Event,newdf$CR0.0001)

##### 1. pH #####
model1 <- glm(CR0.0001~Canal+Event+pH-1,data=newdf,family=Gamma(link="log"))
summary(model1)#AIC=309
plot_model(model1)
plot(newdf$pH,newdf$CR0.0001)

model1q <- glm(CR0.0001~Canal+Event+pH+I(pH^2)-1,data=newdf,family=Gamma(link="log"))
summary(model1q)#AIC=299 - Better

##### 2. Temp #####
model2 <- glm(CR0.0001~Canal+Event+Temp.30da-1,data=newdf,family=Gamma(link="log"))
summary(model2)#AIC=311
plot_model(model2)
plot(newdf$Temp.30da,newdf$CR0.0001)

model2q <- glm(CR0.0001~Canal+Event+Temp.30da+I(Temp.30da^2)-1,data=newdf,family=Gamma(link="log"))
summary(model2q)#AIC=301 - Better

##### 3. Ammonium.mg.L.PW #####
model3 <- glm(CR0.0001~Canal+Event+Ammonium.mg.L.PW-1,data=newdf,family=Gamma(link="log"))
summary(model3)#AIC=311
plot_model(model3)
plot(newdf$Ammonium.mg.L.PW,newdf$CR0.0001)

model3q <- glm(CR0.0001~Canal+Event+Ammonium.mg.L.PW+I(Ammonium.mg.L.PW^2)-1,data=newdf,family=Gamma(link="log"))
summary(model3q)#AIC=310 - Better

##### 4. Bromide.ppb.SW #####
model4 <- glm(CR0.0001~Canal+Event+Bromide.ppb.SW-1,data=newdf,family=Gamma(link="log"))
summary(model4)#AIC=273.7
plot_model(model4)
plot(newdf$Bromide.ppb.SW,newdf$CR0.0001)

model4q <- glm(CR0.0001~Canal+Event+Bromide.ppb.SW+I(Bromide.ppb.SW^2)-1,data=newdf,family=Gamma(link="log"))
summary(model4q)#AIC=272.59 - Better

##### 5. DOC.SW #####
model5 <- glm(CR0.0001~Canal+Event+DOC.mg.L.SW-1,data=newdf,family=Gamma(link="log"))
summary(model5)#AIC=308.46
plot_model(model5)
plot(newdf$DOC.mg.L.SW,newdf$CR0.0001)

model5q <- glm(CR0.0001~Canal+Event+DOC.mg.L.SW+I(DOC.mg.L.SW^2)-1,data=newdf,family=Gamma(link="log"))
summary(model5q)#AIC=298.48 - Better

##### 6. Flow #####
model6 <- glm(CR0.0001~Canal+Event+Flow.cms.30da-1,data=newdf,family=Gamma(link="log"))
summary(model6)#AIC=300.51
plot_model(model6)
plot(newdf$Flow.cms.30da,newdf$CR0.0001)

model6q <- glm(CR0.0001~Canal+Event+Flow.cms.30da+I(Flow.cms.30da^2)-1,data=newdf,family=Gamma(link="log"))
summary(model6q)#AIC=300.78 - Worse

##### 7. pH + Temp #####
model7 <- glm(CR0.0001~Canal+Event+pH+Temp.30da-1,data=newdf,family=Gamma(link="log"))
summary(model7)

##### 8. pH + NH4.PW #####
model8 <- glm(CR0.0001~Canal+Event+pH+Ammonium.mg.L.PW-1,data=newdf,family=Gamma(link="log"))
summary(model8)

##### 9. pH + Br.SW #####
model9 <- glm(CR0.0001~Canal+Event+pH+Bromide.ppb.SW-1,data=newdf,family=Gamma(link="log"))
summary(model9)

##### 10. pH + DOC.SW #####
model10 <- glm(CR0.0001~Canal+Event+pH+DOC.mg.L.SW-1,data=newdf,family=Gamma(link="log"))
summary(model10)

##### 11. pH + Flow #####
model11 <- glm(CR0.0001~Canal+Event+pH+Flow.cms.30da-1,data=newdf,family=Gamma(link="log"))
summary(model11)

##### 12. Temp + NH4.PW #####
model12 <- glm(CR0.0001~Canal+Event+Temp.30da+Ammonium.mg.L.PW-1,data=newdf,family=Gamma(link="log"))
summary(model12)

##### 13. Temp + Br.SW #####
model13 <- glm(CR0.0001~Canal+Event+Temp.30da+Bromide.ppb.SW-1,data=newdf,family=Gamma(link="log"))
summary(model13)

##### 14. Temp + DOC.SW #####
model14 <- glm(CR0.0001~Canal+Event+Temp.30da+DOC.mg.L.SW-1,data=newdf,family=Gamma(link="log"))
summary(model14)

##### 15. Temp + Flow #####
model15 <- glm(CR0.0001~Canal+Event+Temp.30da+Flow.cms.30da-1,data=newdf,family=Gamma(link="log"))
summary(model15)

##### 16. NH4.PW + Br.SW #####
model16 <- glm(CR0.0001~Canal+Event+Ammonium.mg.L.PW+Bromide.ppb.SW-1,data=newdf,family=Gamma(link="log"))
summary(model16)

##### 17. NH4.PW + DOC.SW #####
model17 <- glm(CR0.0001~Canal+Event+Ammonium.mg.L.PW+DOC.mg.L.SW-1,data=newdf,family=Gamma(link="log"))
summary(model17)

##### 18. NH4.PW + Flow #####
model18 <- glm(CR0.0001~Canal+Event+Ammonium.mg.L.PW+Flow.cms.30da-1,data=newdf,family=Gamma(link="log"))
summary(model18)

##### 19. Br.SW + DOC.SW #####
model19 <- glm(CR0.0001~Canal+Event+Bromide.ppb.SW+DOC.mg.L.SW-1,data=newdf,family=Gamma(link="log"))
summary(model19)

##### 20. Br.SW + Flow #####
model20 <- glm(CR0.0001~Canal+Event+Bromide.ppb.SW+Flow.cms.30da-1,data=newdf,family=Gamma(link="log"))
summary(model20)

##### 21. DOC.SW + Flow #####
model21 <- glm(CR0.0001~Canal+Event+DOC.mg.L.SW+Flow.cms.30da-1,data=newdf,family=Gamma(link="log"))
summary(model21)


##### Model comparison w/ AIC #####
models <- list(model1, model2, model3, model4, model5, model6, model1q, model2q, model3q, model4q, model5q, model6q, model7, model8, model9, model10, model11, model12, model13, model14, model15, model16, model17, model18, model19, model20, model21)
model.names <- c('model1', 'model2', 'model3', 'model4', 'model5', 'model6', 'model1q', 'model2q', 'model3q', 'model4q', 'model5q', 'model6q', 'model7', 'model8', 'model9', 'model10', 'model11', 'model12', 'model13', 'model14', 'model15', 'model16', 'model17', 'model18', 'model19', 'model20', 'model21')
aictab(cand.set = models, modnames = model.names)

#Remove bromide models, bromide is messing things up (Even the one var model that worked because I don't trust the low value it resulted in)
models <- list(model1, model2, model3, model5, model6, model1q, model2q, model3q, model5q, model6q, model7, model8, model10, model11, model12, model14, model15, model17, model18, model21)
model.names <- c('model1', 'model2', 'model3', 'model5', 'model6', 'model1q', 'model2q', 'model3q', 'model5q', 'model6q', 'model7', 'model8', 'model10', 'model11', 'model12', 'model14', 'model15', 'model17', 'model18', 'model21')
aictab(cand.set = models, modnames = model.names)
