#Macrophyte GPP Dimension Reduction and GLMs
#Meredith Brehob
#5/10/2022
#This code will reduce the number of covariates that I will input into my GPP model and will run glms on macrophyte GPP data.

#Load packages
library(dplyr)
library(plyr)
library(lme4)
library(AICcmodavg)


#Read in data
df<-read.csv("Data_Final/Environmental_and_CompartmentMetabolism_AllObservations.csv")
plantdf<-subset(df, Substrate=="Plant")


##### Correlations with GPP #####
sub <- plantdf %>% dplyr::select(Canal, Biomass_per_Area:Sed.pH, GPP.mg.per.g.per.hr)#Subset to just site and variable data
gppcor <- ldply(apply(sub[,-1], 2, function(z) cor(x = z, y = sub$GPP.mg.per.g.per.hr, use = "complete.obs", method="kendall")), data.frame) #Create dataframe of correlations with biomass per area
colnames(gppcor)<-c("Variable","Correlation") #Re-name columns

gppp <- ldply(apply(sub[,-1], 2, function(z) cor.test(x = z, y = sub$GPP.mg.per.g.per.hr, use = "complete.obs", method="kendall",exact=F)$p.value), data.frame) #Create dataframe of p-values from above correlations


## Subset covariates
#Remove variables based on correlation coefficients and whether I have hypotheses
GPPdf = subset(plantdf, select = -c(Biomass_per_Area, TSS.mgmL, Ext.Coeff, AQI.30da, SpC.uS.cm., o.Phosphate.ug.L.PW, Ammonium.mg.L.PW, Fluoride.ppb.PW, Nitrite.ppb.PW, Bromide.ppb.PW, Nitrate.ppb.PW, DOC.mg.L.PW, TDN.ug.L.PW, Nitrite.ppb.SW, Bromide.ppb.SW, Nitrate.ppb.SW, Sed.Bulk.Density.g.mL., Sed.pH) )


##### Correlation among variables #####
## For variables without NAs:
mat <-as.matrix(GPPdf[,8:20])#Matrix of covariates
matnoNA <- mat[ , colSums(is.na(mat)) == 0]#Matrix of covariates without NAs
cor_matrix <- cor(matnoNA, method="kendall")#Correlation matrix

##Run separately for variables with NAs:
#Surface water P 
PhosSW <- ldply(apply(GPPdf[,8:20], 2, function(z) cor(x = z, y = GPPdf$o.Phosphate.ug.L.SW, use = "complete.obs", method="kendall")), data.frame)

#Surface water ammonium
AmmonSW <- ldply(apply(GPPdf[,8:20], 2, function(z) cor(x = z, y = GPPdf$Ammonium.mg.L.SW, use = "complete.obs", method="kendall")), data.frame)

#Percent organic matter
OM <- ldply(apply(GPPdf[,8:20], 2, function(z) cor(x = z, y = GPPdf$Sed.PercentOM, use = "complete.obs", method="kendall")), data.frame)


##Subset covariates
#Remove variables based on correlations with each other
GPPdf = subset(GPPdf, select = -c(PM.30da, o.Phosphate.ug.L.SW, Ammonium.mg.L.SW, Fluoride.ppb.SW, TDC.mg.L.SW, TDN.ug.L.SW))


##### Data organization for model input #####
#Make new variable with small value added to remove zeros
GPPdf$GPP0.0001<-GPPdf$GPP.mg.per.g.per.hr+0.0001

#Have to calc ave %OM across event or it isn't comparable to other vars
OMave <- GPPdf %>%
  group_by(Event, Canal) %>%
  summarize(
    PerOM = mean(Sed.PercentOM, na.rm=T)
  )
GPPdf<-left_join(GPPdf, OMave)

## Center data
df_sub <- select(GPPdf, PAR.30da:Flow.cms.30da, PerOM)
df_sub <- apply(df_sub, 2, function(x) (x - mean(x, na.rm=TRUE))/sd(x, na.rm=TRUE))

newdf <- cbind(GPPdf[,c("Canal","Event","GPP0.0001")], df_sub)

#Make event and canal factors
newdf$Event<-as.factor(newdf$Event)
newdf$Canal<-as.factor(newdf$Canal)

#Remove canal A - this is unfortunately necessary to any of the glm algorithms to converge
newdf<-subset(newdf, Canal!="A")

##### 0. Just Canal and Event #####
model0 <- glm(GPP0.0001~Canal+Event-1,data=newdf,family=Gamma(link="log"))
summary(model0)
plot_model(model0)
plot(newdf$Canal,newdf$GPP0.0001)
plot(newdf$Event,newdf$GPP0.0001)

##### 1. PAR #####
model1 <- glm(GPP0.0001~Canal+Event+PAR.30da-1,data=newdf,family=Gamma(link="log"))
summary(model1)
plot_model(model1)
plot(newdf$PAR.30da,newdf$GPP0.0001)

##### 2. pH #####
model2 <- glm(GPP0.0001~Canal+Event+pH-1,data=newdf,family=Gamma(link="log"))
summary(model2)
plot_model(model2)
plot(newdf$pH,newdf$GPP0.0001)

##### 3. Temp #####
model3 <- glm(GPP0.0001~Canal+Event+Temp.30da-1,data=newdf,family=Gamma(link="log"))
summary(model3)
plot_model(model3)
plot(newdf$Temp.30da,newdf$GPP0.0001)

##### 4. TDC.PW #####
model4 <- glm(GPP0.0001~Canal+Event+TDC.mg.L.PW-1,data=newdf,family=Gamma(link="log"))
summary(model4)
plot_model(model4)
plot(newdf$TDC.mg.L.PW,newdf$GPP0.0001)

##### 5. DOC.SW #####
model5 <- glm(GPP0.0001~Canal+Event+DOC.mg.L.SW-1,data=newdf,family=Gamma(link="log"))
summary(model5)
plot_model(model5)
plot(newdf$DOC.mg.L.SW,newdf$GPP0.0001)

##### 6. Flow #####
model6 <- glm(GPP0.0001~Canal+Event+Flow.cms.30da-1,data=newdf,family=Gamma(link="log"))
summary(model6)
plot_model(model6)
plot(newdf$Flow.cms.30da,newdf$GPP0.0001)

##### 7. %OM #####
model7 <- glm(GPP0.0001~Canal+Event+PerOM-1,data=newdf,family=Gamma(link="log"))
summary(model7)
plot_model(model7)
plot(newdf$PerOM,newdf$GPP0.0001)


##### Model comparison w/ AIC #####
models <- list(model1, model2, model3, model4, model5, model6, model7)
model.names <- c('model1', 'model2', 'model3', 'model4', 'model5', 'model6', 'model7')
aictab(cand.set = models, modnames = model.names)
