#Sediment ER Dimension Reduction and GLMs
#Meredith Brehob
#5/10/2022
#This code will reduce the number of covariates that I will input into my sediment ER model and will run glms on ER data.

#Load packages
library(dplyr)
library(plyr)
library(lme4)
library(AICcmodavg)


#Read in data
df<-read.csv("Data_Final/Environmental_and_CompartmentMetabolism_AllObservations.csv")
seddf<-subset(df, Substrate=="Sed")


##### Correlations with CR #####
sub <- seddf %>% dplyr::select(Canal, Biomass_per_Area:Sed.pH, CR.mg.per.g.per.hr)#Subset to just site and variable data
crcor <- ldply(apply(sub[,-1], 2, function(z) cor(x = z, y = sub$CR.mg.per.g.per.hr, use = "complete.obs", method="kendall")), data.frame) #Create dataframe of correlations with biomass per area
colnames(crcor)<-c("Variable","Correlation") #Re-name columns

crp <- ldply(apply(sub[,-1], 2, function(z) cor.test(x = z, y = sub$CR.mg.per.g.per.hr, use = "complete.obs", method="kendall",exact=F)$p.value), data.frame) #Create dataframe of p-values from above correlations

## Subset covariates
#Remove variables based on correlation coefficients and whether I have hypotheses
CRdf = subset(seddf, select = -c(Biomass_per_Area, TSS.mgmL, Ext.Coeff, AQI.30da, PAR.30da, SpC.uS.cm., pH, Temp.30da, o.Phosphate.ug.L.PW, Nitrite.ppb.PW, Bromide.ppb.PW, Nitrate.ppb.PW, TDC.mg.L.PW, Ammonium.mg.L.SW, Nitrite.ppb.SW, Bromide.ppb.SW, Nitrate.ppb.SW, DOC.mg.L.SW, TDN.ug.L.SW, Sed.Bulk.Density.g.mL., Sed.PercentOM, Sed.pH) )


##### Correlation among variables #####
## For variables without NAs:
mat <-as.matrix(CRdf[,8:16])#Matrix of covariates
matnoNA <- mat[ , colSums(is.na(mat)) == 0]#Matrix of covariates without NAs
cor_matrix <- cor(matnoNA, method="kendall")#Correlation matrix

##Run separately for variables with NAs:
#Porewater DOC
DOCPW <- ldply(apply(CRdf[,8:16], 2, function(z) cor(x = z, y = CRdf$DOC.mg.L.PW, use = "complete.obs", method="kendall")), data.frame)

#Porewater TDN
TDNPW <- ldply(apply(CRdf[,8:16], 2, function(z) cor(x = z, y = CRdf$TDN.ug.L.PW, use = "complete.obs", method="kendall")), data.frame)

#Surface water oPhos
PhosSW <- ldply(apply(CRdf[,8:16], 2, function(z) cor(x = z, y = CRdf$o.Phosphate.ug.L.SW, use = "complete.obs", method="kendall")), data.frame)

## Subset covariates
#Remove variables based on correlations with each other
CRdf = subset(CRdf, select = -c(PM.30da, TDN.ug.L.PW, o.Phosphate.ug.L.SW, Fluoride.ppb.SW))


##### Data organization for model input #####
#Make new variable with small value added to remove zeros
CRdf$CR0.0001<-CRdf$CR.mg.per.g.per.hr+0.0001

## Center data
df_sub <- select(CRdf, Ammonium.mg.L.PW:Flow.cms.30da)
df_sub <- apply(df_sub, 2, function(x) (x - mean(x, na.rm=TRUE))/sd(x, na.rm=TRUE))
newdf <- cbind(CRdf[,c("Canal","Event","CR0.0001")], df_sub)

#Make event and canal factors
newdf$Event<-as.factor(newdf$Event)
newdf$Canal<-as.factor(newdf$Canal)

#Remove NAs - vars w/ fewer obs result in lower AIC vals
newdf<-newdf[complete.cases(newdf), ]


##### 0. Just Canal and Event #####
model0 <- glm(CR0.0001~Canal+Event-1,data=newdf,family=Gamma(link="log"))
summary(model0)#AIC=139
plot_model(model0)
plot(newdf$Canal,newdf$CR0.0001)
plot(newdf$Event,newdf$CR0.0001)

##### 1. NH4.PW #####
model1 <- glm(CR0.0001~Canal+Event+Ammonium.mg.L.PW-1,data=newdf,family=Gamma(link="log"))
summary(model1)#AIC=139
plot_model(model1)
plot(newdf$Ammonium.mg.L.PW,newdf$CR0.0001)

model1q <- glm(CR0.0001~Canal+Event+Ammonium.mg.L.PW+I(Ammonium.mg.L.PW^2)-1,data=newdf,family=Gamma(link="log"))
summary(model1q)#AIC=141 - Worse

##### 2. Fl.PW #####
model2 <- glm(CR0.0001~Canal+Event+Fluoride.ppb.PW-1,data=newdf,family=Gamma(link="log"))
summary(model2)#AIC=141
plot_model(model2)
plot(newdf$Fluoride.ppb.PW,newdf$CR0.0001)

model2q <- glm(CR0.0001~Canal+Event+Fluoride.ppb.PW+I(Fluoride.ppb.PW^2)-1,data=newdf,family=Gamma(link="log"))
summary(model2q)#AIC=140 - Better

##### 3. DOC.PW #####
model3 <- glm(CR0.0001~Canal+Event+DOC.mg.L.PW-1,data=newdf,family=Gamma(link="log"))
summary(model3)#AIC=108
plot_model(model3)
plot(newdf$DOC.mg.L.PW,newdf$CR0.0001)

model3q <- glm(CR0.0001~Canal+Event+DOC.mg.L.PW+I(DOC.mg.L.PW^2)-1,data=newdf,family=Gamma(link="log"))
summary(model3q)#AIC=68.714 - Better

##### 4. TDC.SW #####
model4 <- glm(CR0.0001~Canal+Event+TDC.mg.L.SW-1,data=newdf,family=Gamma(link="log"))
summary(model4)#AIC=136
plot_model(model4)
plot(newdf$TDC.mg.L.SW,newdf$CR0.0001)

model4q <- glm(CR0.0001~Canal+Event+TDC.mg.L.SW+I(TDC.mg.L.SW^2)-1,data=newdf,family=Gamma(link="log"))
summary(model4q)#AIC=127 - Better

##### 5. Flow #####
model5 <- glm(CR0.0001~Canal+Event+Flow.cms.30da-1,data=newdf,family=Gamma(link="log"))
summary(model5)#AIC=136
plot_model(model5)
plot(newdf$Flow.cms.30da,newdf$CR0.0001)

model5q <- glm(CR0.0001~Canal+Event+Flow.cms.30da+I(Flow.cms.30da^2)-1,data=newdf,family=Gamma(link="log"))
summary(model5q)#AIC=107.66 - Better

##### 6. NH4.PW + Fl.PW #####
model6 <- glm(CR0.0001~Canal+Event+Ammonium.mg.L.PW+Fluoride.ppb.PW-1,data=newdf,family=Gamma(link="log"))
summary(model6)

##### 7. NH4.PW + DOC.PW #####
model7 <- glm(CR0.0001~Canal+Event+Ammonium.mg.L.PW+DOC.mg.L.PW-1,data=newdf,family=Gamma(link="log"))
summary(model7)

##### 8. NH4.PW + TDC.SW #####
model8 <- glm(CR0.0001~Canal+Event+Ammonium.mg.L.PW+TDC.mg.L.SW-1,data=newdf,family=Gamma(link="log"))
summary(model8)

##### 9. NH4.PW + Flow #####
model9 <- glm(CR0.0001~Canal+Event+Ammonium.mg.L.PW+Flow.cms.30da-1,data=newdf,family=Gamma(link="log"))
summary(model9)

##### 10. Fl.PW + DOC.PW #####
model10 <- glm(CR0.0001~Canal+Event+Fluoride.ppb.PW+DOC.mg.L.PW-1,data=newdf,family=Gamma(link="log"))
summary(model10)

##### 11. Fl.PW + TDC.SW #####
model11 <- glm(CR0.0001~Canal+Event+Fluoride.ppb.PW+TDC.mg.L.SW-1,data=newdf,family=Gamma(link="log"))
summary(model11)

##### 12. Fl.PW + Flow #####
model12 <- glm(CR0.0001~Canal+Event+Fluoride.ppb.PW+Flow.cms.30da-1,data=newdf,family=Gamma(link="log"))
summary(model12)

##### 13. DOC.PW + TDC.SW #####
model13 <- glm(CR0.0001~Canal+Event+DOC.mg.L.PW+TDC.mg.L.SW-1,data=newdf,family=Gamma(link="log"))
summary(model13)

##### 14. DOC.PW + Flow #####
model14 <- glm(CR0.0001~Canal+Event+DOC.mg.L.PW+Flow.cms.30da-1,data=newdf,family=Gamma(link="log"))
summary(model14)

##### 15. TDC.SW + Flow #####
model15 <- glm(CR0.0001~Canal+Event+TDC.mg.L.SW+Flow.cms.30da-1,data=newdf,family=Gamma(link="log"))
summary(model15)


##### Model comparison w/ AIC #####
models <- list(model1, model2, model3, model4, model5, model6, model1q, model2q, model3q, model4q, model5q, model7, model8, model9, model10, model11, model12, model13, model14, model15)
model.names <- c('model1', 'model2', 'model3', 'model4', 'model5', 'model6', 'model1q', 'model2q', 'model3q', 'model4q', 'model5q', 'model7', 'model8', 'model9', 'model10', 'model11', 'model12', 'model13', 'model14', 'model15')
aictab(cand.set = models, modnames = model.names)
