#Macrophyte Density Models
#Meredith Brehob
#5/9/2022
#This code will use bivariate analysis to reduce the number of covariates and will then perform generalized linear models with macrophyte density as the response variable.

#Load packages
library(dplyr)
library(plyr)
library(lme4)
library(DHARMa)
library(sjPlot)
library(ggplot2)
library(tidyverse)
library(cowplot)
library(AICcmodavg)

#Read in data
df<-read.csv("Data_Final/Environmental_and_Macrophyte_AllObservations.csv")
df<-df[,-c(37:43)]#Remove composition data


##### Correlations with biomass per area #####
sub <- df %>% dplyr::select(Canal, Biomass_per_Area:Sed.pH) #Subset to just site and variable data
bpacor <- ldply(apply(sub[,-1], 2, function(z) cor(x = z, y = sub$Biomass_per_Area, use = "complete.obs", method="kendall")), data.frame) #Create dataframe of correlations with biomass per area
colnames(bpacor)<-c("Variable","Correlation") #Re-name columns

bpap <- ldply(apply(sub[,-1], 2, function(z) cor.test(x = z, y = sub$Biomass_per_Area, use = "complete.obs", method="kendall",exact=F)$p.value), data.frame) #Create dataframe of p-values from above correlations


## Subset covariates
#Remove variables based on correlation coefficients < 0.15 / p-values > 0.05
df = subset(df, select = -c(Ext.Coeff, AQI.30da, PM.30da, SpC.uS.cm., pH, Temp.30da, o.Phosphate.ug.L.PW, Nitrite.ppb.PW, Bromide.ppb.PW, Nitrate.ppb.PW, TDC.mg.L.PW, o.Phosphate.ug.L.SW, Ammonium.mg.L.SW, Fluoride.ppb.SW, Nitrite.ppb.SW, Bromide.ppb.SW, TDC.mg.L.SW, Sed.Bulk.Density.g.mL., Sed.PercentOM, Sed.pH) )


##### Correlation among variables #####
## For variables without NAs:
mat <-as.matrix(df[,7:16])#Matrix of covariates
matnoNA <- mat[ , colSums(is.na(mat)) == 0]#Matrix of covariates without NAs
cor_matrix <- cor(matnoNA, method="kendall")#Correlation matrix

##Run separately for variables with NAs:
#Porewater DOC 
DOCPW <- ldply(apply(df[,7:16], 2, function(z) cor(x = z, y = df$DOC.mg.L.PW, use = "complete.obs", method="kendall")), data.frame)

#Porewater TDN
TDNPW <- ldply(apply(df[,7:16], 2, function(z) cor(x = z, y = df$TDN.ug.L.PW, use = "complete.obs", method="kendall")), data.frame)

#Surface water nitrate
NO3SW <- ldply(apply(df[,7:16], 2, function(z) cor(x = z, y = df$Nitrate.ppb.SW, use = "complete.obs", method="kendall")), data.frame)


## Subset covariates 
#Remove variables based on correlations with each other (coefficient > 0.7)
df = subset(df, select = -c(Ammonium.mg.L.PW, Fluoride.ppb.PW, DOC.mg.L.PW) )


##### Data organization for model input #####
# Remove nitrate because it is a component of TDN
df$Nitrate.ppb.SW <- NULL

#Remove canal A event 3 because there is unexplained zero data during this event
df<-subset(df, Canal!="A" | Event!="3")

#Make new variable with small value added to remove zeros
df$Biomass0.0001<-df$Biomass_per_Area+0.0001

## Center data
df_sub <- select(df, TSS.mgmL:Flow.cms.30da)
df_sub <- apply(df_sub, 2, function(x) (x - mean(x))/sd(x))
newdf <- cbind(df[,c("Canal","Event","Biomass0.0001")], df_sub)

#Make event and canal factors
newdf$Event<-as.factor(newdf$Event)
newdf$Canal<-as.factor(newdf$Canal)


##### 0. Just Canal and Event #####
model0 <- glm(Biomass0.0001~Canal+Event-1,data=newdf,family=Gamma(link="log"))
summary(model0)
plot_model(model0)
plot(newdf$Canal,newdf$Biomass0.0001)
plot(newdf$Event,newdf$Biomass0.0001)

##### 1. TSS #####
model1 <- glm(Biomass0.0001~Canal+Event+TSS.mgmL-1,data=newdf,family=Gamma(link="log"))
summary(model1)
plot_model(model1)
plot(newdf$TSS.mgmL,newdf$Biomass0.0001)

model1q <- glm(Biomass0.0001~Canal+Event+TSS.mgmL+I(TSS.mgmL^2)-1,data=newdf,family=Gamma(link="log"))
summary(model1q)#Worse AIC with quadratic

##### 2. PAR #####
model2 <- glm(Biomass0.0001~Canal+Event+PAR.30da-1,data=newdf,family=Gamma(link="log"))
summary(model2)
plot_model(model2)
plot(newdf$PAR.30da,newdf$Biomass0.0001)

model2q <- glm(Biomass0.0001~Canal+Event+PAR.30da+I(PAR.30da^2)-1,data=newdf,family=Gamma(link="log"))
summary(model2q)#Worse AIC with quadratic

##### 3. TDN.PW #####
model3 <- glm(Biomass0.0001~Canal+Event+TDN.ug.L.PW-1,data=newdf,family=Gamma(link="log"))
summary(model3)
plot_model(model3)
plot(newdf$TDN.ug.L.PW,newdf$Biomass0.0001)

model3q <- glm(Biomass0.0001~Canal+Event+TDN.ug.L.PW+I(TDN.ug.L.PW^2)-1,data=newdf,family=Gamma(link="log"))
summary(model3q)#Worse AIC with quadratic

##### 4. DOC.SW #####
model4 <- glm(Biomass0.0001~Canal+Event+DOC.mg.L.SW-1,data=newdf,family=Gamma(link="log"))
summary(model4)
plot_model(model4)
plot(newdf$DOC.mg.L.SW,newdf$Biomass0.0001)

model4q <- glm(Biomass0.0001~Canal+Event+DOC.mg.L.SW+I(DOC.mg.L.SW^2)-1,data=newdf,family=Gamma(link="log"))
summary(model4q)#Worse AIC with quadratic

##### 5. TDN.SW #####
model5 <- glm(Biomass0.0001~Canal+Event+TDN.ug.L.SW-1,data=newdf,family=Gamma(link="log"))
summary(model5)
plot_model(model5)
plot(newdf$TDN.ug.L.SW,newdf$Biomass0.0001)

model5q <- glm(Biomass0.0001~Canal+Event+TDN.ug.L.SW+I(TDN.ug.L.SW^2)-1,data=newdf,family=Gamma(link="log"))
summary(model5q)#Better AIC with quadratic

##### 6. Flow #####
model6 <- glm(Biomass0.0001~Canal+Event+Flow.cms.30da-1,data=newdf,family=Gamma(link="log"))
summary(model6)
plot_model(model6)
plot(newdf$Flow.cms.30da,newdf$Biomass0.0001)

model6q <- glm(Biomass0.0001~Canal+Event+Flow.cms.30da+I(Flow.cms.30da^2)-1,data=newdf,family=Gamma(link="log"))
summary(model6q)#Better AIC with quadratic

##### 7. TSS + PAR #####
model7 <- glm(Biomass0.0001~Canal+Event+TSS.mgmL+PAR.30da-1,data=newdf,family=Gamma(link="log"))
summary(model7)

##### 8. TSS + TDN.PW #####
model8 <- glm(Biomass0.0001~Canal+Event+TSS.mgmL+TDN.ug.L.PW-1,data=newdf,family=Gamma(link="log"))
summary(model8)

##### 9. TSS + DOC.SW #####
model9 <- glm(Biomass0.0001~Canal+Event+TSS.mgmL+DOC.mg.L.SW-1,data=newdf,family=Gamma(link="log"))
summary(model9)

##### 10. TSS + TDN.SW #####
model10 <- glm(Biomass0.0001~Canal+Event+TSS.mgmL+TDN.ug.L.SW-1,data=newdf,family=Gamma(link="log"))
summary(model10)

##### 11. TSS + Flow #####
model11 <- glm(Biomass0.0001~Canal+Event+TSS.mgmL+Flow.cms.30da-1,data=newdf,family=Gamma(link="log"))
summary(model11)

##### 12. PAR + TDN.PW #####
model12 <- glm(Biomass0.0001~Canal+Event+PAR.30da+TDN.ug.L.PW-1,data=newdf,family=Gamma(link="log"))
summary(model12)

##### 13. PAR + DOC.SW #####
model13 <- glm(Biomass0.0001~Canal+Event+PAR.30da+DOC.mg.L.SW-1,data=newdf,family=Gamma(link="log"))
summary(model13)

##### 14. PAR + TDN.SW #####
model14 <- glm(Biomass0.0001~Canal+Event+PAR.30da+TDN.ug.L.SW-1,data=newdf,family=Gamma(link="log"))
summary(model14)

##### 15. PAR + Flow #####
model15 <- glm(Biomass0.0001~Canal+Event+PAR.30da+Flow.cms.30da-1,data=newdf,family=Gamma(link="log"))
summary(model15)

##### 16. TDN.PW + DOC.SW #####
model16 <- glm(Biomass0.0001~Canal+Event+TDN.ug.L.PW+DOC.mg.L.SW-1,data=newdf,family=Gamma(link="log"))
summary(model16)

##### 17. TDN.PW + TDN.SW #####
model17 <- glm(Biomass0.0001~Canal+Event+TDN.ug.L.PW+TDN.ug.L.SW-1,data=newdf,family=Gamma(link="log"))
summary(model17)

##### 18. TDN.PW + Flow #####
model18 <- glm(Biomass0.0001~Canal+Event+TDN.ug.L.PW+Flow.cms.30da-1,data=newdf,family=Gamma(link="log"))
summary(model18)

##### 19. DOC.SW + TDN.SW #####
model19 <- glm(Biomass0.0001~Canal+Event+DOC.mg.L.SW+TDN.ug.L.SW-1,data=newdf,family=Gamma(link="log"))
summary(model19)

##### 20. DOC.SW + Flow #####
model20 <- glm(Biomass0.0001~Canal+Event+DOC.mg.L.SW+Flow.cms.30da-1,data=newdf,family=Gamma(link="log"))
summary(model20)

##### 21. TDN.SW + Flow #####
model21 <- glm(Biomass0.0001~Canal+Event+TDN.ug.L.SW+Flow.cms.30da-1,data=newdf,family=Gamma(link="log"))
summary(model21)

#Not enough interpretability to be able to add interactions or quadratic effects to models with more than one covariate.

##### Model comparison w/ AIC #####
models <- list(model1, model2, model3, model4, model5, model6, model1q, model2q, model3q, model4q, model5q, model6q, model7, model8, model9, model10, model11, model12, model13, model14, model15, model16, model17, model18, model19, model20, model21)
model.names <- c('model1', 'model2', 'model3', 'model4', 'model5', 'model6', 'model1q', 'model2q', 'model3q', 'model4q', 'model5q', 'model6q', 'model7', 'model8', 'model9', 'model10', 'model11', 'model12', 'model13', 'model14', 'model15', 'model16', 'model17', 'model18', 'model19', 'model20', 'model21')
aictab(cand.set = models, modnames = model.names)


##### Plot of best model comparisons #####
plot_models(model1, model3, model9, model8, transform=NULL)+
  scale_color_brewer(name="Model",labels = c("8", "9", "3", "1"),palette = "Dark2")+theme_bw()

#Stacked plots for models with one environmental variable
set_theme(base = theme_bw())
p1<-plot_model(model1, axis.lim=c(-2,2), terms = c("TSS.mgmL"), axis.labels = c("TSS"), transform = NULL)+theme(axis.text=element_text(size=10, face="bold"), plot.title = element_blank(), axis.text.x = element_blank(), axis.text.y = element_text(size=10), axis.title.x = element_blank(), axis.ticks.x = element_blank(), plot.margin = unit(c(0, 0.25, 0, 0), "cm"))
p2<-plot_model(model2, axis.lim=c(-2,2), terms = c("PAR.30da"), axis.labels = c("Surface Light"), transform = NULL) + theme(axis.text.x = element_blank(), axis.text.y = element_text(size=10), axis.title.x = element_blank(), axis.ticks.x = element_blank(), plot.title = element_blank(), plot.margin = unit(c(0, 0.25, 0, 0), "cm"))
p3<-plot_model(model3, axis.lim=c(-2,2), terms = c("TDN.ug.L.PW"), axis.labels = c("TDN.PW"), transform = NULL)+ theme(axis.text.x = element_blank(), axis.title.x = element_blank(), axis.ticks.x = element_blank(), axis.text.y = element_text(size = 10), plot.title = element_blank(), plot.margin = unit(c(0, 0.25, 0, 0), "cm"))
p4<-plot_model(model4, axis.lim=c(-2,2), terms = c("DOC.mg.L.SW"), axis.labels = c("DOC.SW"), transform = NULL)+ theme(axis.text.x = element_blank(), axis.title.x = element_blank(), axis.ticks.x = element_blank(), axis.text.y = element_text(size = 10), plot.title = element_blank(), plot.margin = unit(c(0, 0.25, 0, 0.25), "cm"))
p5<-plot_model(model5, axis.lim=c(-2,2), terms = c("TDN.ug.L.SW"), axis.labels = c("TDN.SW"), transform = NULL)+ theme(axis.text.x = element_blank(), axis.title.x = element_blank(), axis.ticks.x = element_blank(), axis.text.y = element_text(size = 10), plot.title = element_blank(), plot.margin = unit(c(0, 0.25, 0, 0), "cm"))
p6<-plot_model(model6, axis.lim=c(-2,2), terms = c("Flow.cms.30da"), axis.labels = c("Flow"), transform = NULL)+theme(axis.text=element_text(size=10), axis.text.y = element_text(size=10), plot.title = element_blank(), plot.margin = unit(c(0, 0.25, 0, 0), "cm"))

cowplot::plot_grid(p1, p2, p3, p4, p5, p6, ncol=1, align="v", rel_heights = c(1,1,1,1,1,1.65))


##### Plot of predicted biomass per TSS per canal - not centered data #####
#New model without event effect - just to observe the effect of canal
df$TSS.ugmL <- df$TSS.mgmL*1000#Convert to ug/mL

model1canal <- glm(Biomass0.0001~Canal+TSS.ugmL-1,data=df,family=Gamma(link="log"))
parseq <- seq(min(df$TSS.ugmL),max(df$TSS.ugmL),length=100)

#Predictions for A-Line canal
ndA <- data.frame(TSS.ugmL = parseq)
ndA$Canal = factor(levels(as.factor(df$Canal))[1],levels=levels(as.factor(df$Canal)))
mypredA <- predict(model1canal,newdata = ndA,type = "response",se.fit=T)

#Predictions for Upstream L-Line canal
ndD <- data.frame(TSS.ugmL = parseq)
ndD$Canal = factor(levels(as.factor(df$Canal))[3],levels=levels(as.factor(df$Canal)))
mypredD <- predict(model1canal,newdata = ndD,type = "response",se.fit=T)

#Predictions for Downstream L-Line canal
ndM <- data.frame(TSS.ugmL = parseq)
ndM$Canal = factor(levels(as.factor(df$Canal))[2],levels=levels(as.factor(df$Canal)))
mypredM <- predict(model1canal,newdata = ndM,type = "response",se.fit=T)

#Plot predictions and raw data
ggplot(x=ndA$TSS.ugmL, y=mypredA$fit)+
  geom_line(aes(x=ndA$TSS.ugmL, y=mypredA$fit), col='#85AD1F')+
  geom_ribbon(aes(x=ndA$TSS.ugmL, ymin=mypredA$fit-mypredA$se.fit, ymax=mypredA$fit+mypredA$se.fit), fill='#85AD1F', alpha=0.2)+
  geom_line(aes(x=ndD$TSS.ugmL, y=mypredD$fit), col='#FA492D')+
  geom_ribbon(aes(x=ndD$TSS.ugmL, ymin=mypredD$fit-mypredD$se.fit, ymax=mypredD$fit+mypredD$se.fit), fill='#FA492D', alpha=0.2)+
  geom_line(aes(x=ndM$TSS.ugmL, y=mypredM$fit), col='#5F98FA')+
  geom_ribbon(aes(x=ndM$TSS.ugmL, ymin=mypredM$fit-mypredM$se.fit, ymax=mypredM$fit+mypredM$se.fit), fill='#5F98FA', alpha=0.2)+
  geom_point(aes(x=df$TSS.ugmL, y=df$Biomass0.0001, col=df$Canal))+
  theme_bw()+
  scale_color_manual(values = c("UL" = "#FA492D", "DL" = "#5F98FA", "A" = "#85AD1F"))+
  labs(y=expression(paste("Biomass per area (g/", m^2,")")), x=expression(paste("Total Suspended Solids (TSS) (", mu,"g/mL)")), col="Canal")+
  theme(panel.grid.minor = element_blank())

#Plot just raw data
ggplot(data=df, aes(x=TSS.ugmL, y=Biomass0.0001, col=Canal))+
  geom_point()+
  theme_bw()+
  scale_color_manual(values = c("UL" = "#FA492D", "DL" = "#5F98FA", "A" = "#85AD1F"))+
  labs(y=expression(paste("Biomass per area (g/", m^2,")")), x=expression(paste("Total Suspended Solids (TSS) (", mu,"g/mL)")), col="Canal")+
  theme(panel.grid.minor = element_blank())
