#Macrophyte Diversity Models
#Meredith Brehob
#5/9/2022
#This code will use bivariate analysis to reduce the number of covariates and will then perform generalized linear models with macrophyte diversity as the response variable.

#Load packages
library(dplyr)
library(plyr)
library(lme4)
library(lme4)
library(DHARMa)
library(sjPlot)
library(ggplot2)
library(tidyverse)
library(cowplot)
library(AICcmodavg)

#Read in data
df<-read.csv("Data_Final/Environmental_and_Macrophyte_AllObservations.csv")
df<-df[complete.cases(df[ , 43]),]#Remove rows with no genus data


##### Correlations with Shannon's Diversity Index #####
sub <- df %>% dplyr::select(Canal, TSS.mgmL:Sed.pH, SDI) #Subset to just site and variable data
bpacor <- ldply(apply(sub[,-1], 2, function(z) cor(x = z, y = sub$SDI, use = "complete.obs", method="kendall")), data.frame) #Create dataframe of correlations with SDInon's diversity index
colnames(bpacor)<-c("Variable","Correlation") #Re-name columns

bpap <- ldply(apply(sub[,-1], 2, function(z) cor.test(x = z, y = sub$SDI, use = "complete.obs", method="kendall",exact=F)$p.value), data.frame) #Create dataframe of p-values from above correlations


## Subset covariates
#Remove variables based on correlation coefficients < 0.15 / p-values > 0.05
df = subset(df, select = -c(TSS.mgmL, Ext.Coeff, PAR.30da, AQI.30da, PM.30da, pH, Temp.30da, o.Phosphate.ug.L.PW, Nitrite.ppb.PW, Bromide.ppb.PW, Nitrate.ppb.PW, o.Phosphate.ug.L.SW, Fluoride.ppb.SW, Nitrite.ppb.SW, TDC.mg.L.SW, DOC.mg.L.SW, TDN.ug.L.SW, Flow.cms.30da, Sed.Bulk.Density.g.mL., Sed.pH) )


##### Correlation among variables #####
## For variables without NAs:
mat <-as.matrix(df[,7:16])#Matrix of covariates
matnoNA <- mat[ , colSums(is.na(mat)) == 0]#Matrix of covariates without NAs
cor_matrix <- cor(matnoNA, method="kendall")#Correlation matrix

##Run separately for variables with NAs:

#Porewater TDC
TDCPW <- ldply(apply(df[,7:16], 2, function(z) cor(x = z, y = df$TDC.mg.L.PW, use = "complete.obs", method="kendall")), data.frame)

#Porewater DOC
DOCPW <- ldply(apply(df[,7:16], 2, function(z) cor(x = z, y = df$DOC.mg.L.PW, use = "complete.obs", method="kendall")), data.frame)

#Porewater TDN
TDNPW <- ldply(apply(df[,7:16], 2, function(z) cor(x = z, y = df$TDN.ug.L.PW, use = "complete.obs", method="kendall")), data.frame)

#Surface water ammonium
AmmonSW <- ldply(apply(df[,7:16], 2, function(z) cor(x = z, y = df$Ammonium.mg.L.SW, use = "complete.obs", method="kendall")), data.frame)

#Surface water bromide
BrSW <- ldply(apply(df[,7:16], 2, function(z) cor(x = z, y = df$Bromide.ppb.SW, use = "complete.obs", method="kendall")), data.frame)

#Surface water nitrate
NO3SW <- ldply(apply(df[,7:16], 2, function(z) cor(x = z, y = df$Nitrate.ppb.SW, use = "complete.obs", method="kendall")), data.frame)

#Percent organic matter
PerOM <- ldply(apply(df[,7:16], 2, function(z) cor(x = z, y = df$Sed.PercentOM, use = "complete.obs", method="kendall")), data.frame)


## Subset covariates 
#Remove variables based on correlations with each other (coefficient > 0.7)
df = subset(df, select = -c(Ammonium.mg.L.PW, Fluoride.ppb.PW, DOC.mg.L.PW) )


##### Data organization for model input #####
#Make event and canal factors
df$Event<-as.factor(df$Event)
df$Canal<-as.factor(df$Canal)

#Make new variable with small value added to remove zeros
df$SDI0.0001<-df$SDI+0.0001

## Center data
df_sub <- select(df, SpC.uS.cm.:Sed.PercentOM)
df_sub <- apply(df_sub, 2, function(x) (x - mean(x, na.rm=TRUE))/sd(x, na.rm=TRUE))
newdf <- cbind(df[,c("Canal","Event","SDI0.0001")], df_sub)

##### 0. Just Canal and Event #####
model0 <- glm(SDI0.0001~Canal+Event-1,data=newdf,family=Gamma(link="log"))
summary(model0)
plot_model(model0)
plot(newdf$Canal,newdf$SDI0.0001)
plot(newdf$Event,newdf$SDI0.0001)

##### 1. SpC #####
model1 <- glm(SDI0.0001~Canal+Event+SpC.uS.cm.-1,data=newdf,family=Gamma(link="log"))
summary(model1)
plot_model(model1)
plot(newdf$SpC.uS.cm.,newdf$SDI0.0001)

model1q <- glm(SDI0.0001~Canal+Event+SpC.uS.cm.+I(SpC.uS.cm.^2)-1,data=newdf,family=Gamma(link="log"))
summary(model1q)

##### 2. TDC.PW #####
model2 <- glm(SDI0.0001~Canal+Event+TDC.mg.L.PW-1,data=newdf,family=Gamma(link="log"))
summary(model2)
plot_model(model2)
plot(newdf$TDC.mg.L.PW,newdf$SDI0.0001)

model2q <- glm(SDI0.0001~Canal+Event+TDC.mg.L.PW+I(TDC.mg.L.PW^2)-1,data=newdf,family=Gamma(link="log"))
summary(model2q)

##### 3. TDN.PW #####
model3 <- glm(SDI0.0001~Canal+Event+TDN.ug.L.PW-1,data=newdf,family=Gamma(link="log"))
summary(model3)
plot_model(model3)
plot(newdf$TDN.ug.L.PW,newdf$SDI0.0001)

model3q <- glm(SDI0.0001~Canal+Event+TDN.ug.L.PW+I(TDN.ug.L.PW^2)-1,data=newdf,family=Gamma(link="log"))
summary(model3q)

##### 4. NH4.SW #####
model4 <- glm(SDI0.0001~Canal+Event+Ammonium.mg.L.SW-1,data=newdf,family=Gamma(link="log"))
summary(model4)
plot_model(model4)
plot(newdf$Ammonium.mg.L.SW,newdf$SDI0.0001)

model4q <- glm(SDI0.0001~Canal+Event+Ammonium.mg.L.SW+I(Ammonium.mg.L.SW^2)-1,data=newdf,family=Gamma(link="log"))
summary(model4q)

##### 5. Br.SW #####
model5 <- glm(SDI0.0001~Canal+Event+Bromide.ppb.SW-1,data=newdf,family=Gamma(link="log"))
summary(model5)
plot_model(model5)
plot(newdf$Bromide.ppb.SW,newdf$SDI0.0001)

model5q <- glm(SDI0.0001~Canal+Event+Bromide.ppb.SW+I(Bromide.ppb.SW^2)-1,data=newdf,family=Gamma(link="log"))#ERROR
summary(model5q)

##### 6. NO3.SW #####
model6 <- glm(SDI0.0001~Canal+Event+Nitrate.ppb.SW-1,data=newdf,family=Gamma(link="log"))
summary(model6)
plot_model(model6)
plot(newdf$Nitrate.ppb.SW,newdf$SDI0.0001)

model6q <- glm(SDI0.0001~Canal+Event+Nitrate.ppb.SW+I(Nitrate.ppb.SW^2)-1,data=newdf,family=Gamma(link="log"))
summary(model6q)

##### 7. %OM #####
model7 <- glm(SDI0.0001~Canal+Event+Sed.PercentOM-1,data=newdf,family=Gamma(link="log"))
summary(model7)
plot_model(model7)
plot(newdf$Sed.PercentOM,newdf$SDI0.0001)

model7q <- glm(SDI0.0001~Canal+Event+Sed.PercentOM+I(Sed.PercentOM^2)-1,data=newdf,family=Gamma(link="log"))
summary(model7q)


##### Model comparison with AIC #####
models <- list(model1, model2, model3, model4, model5, model6, model1q, model2q, model3q, model4q, model5q, model6q, model7, model7q)
model.names <- c('model1', 'model2', 'model3', 'model4', 'model5', 'model6', 'model1q', 'model2q', 'model3q', 'model4q', 'model5q', 'model6q', 'model7', 'model7q')
aictab(cand.set = models, modnames = model.names)
