#Seasonal and Site Variation in Macrophyte Density, Macrophyte Composition, and Environmental Conditions
#Meredith Brehob
#5/9/2022
#This code will run Kruskal-Wallis tests for biomass, genus, and environmental data for the final sets of variables for models.

library(ggplot2)
library(tidyverse)

#Read in data
df<-read.csv("Data_Final/Environmental_and_Macrophyte_AllObservations.csv")

#Make Canal and Event factors
df$Event<-as.factor(df$Event)
df$Canal<-as.factor(df$Canal)


##### Macrophyte Density #####
#Used Kruskal Wallis and Wilcox tests for biomass due to violation of assumptions of ANOVA.

## Seasonal variation
#All canals
kruskal.test(Biomass_per_Area ~ Event, data = df)
pairwise.wilcox.test(df$Biomass_per_Area, df$Event, p.adjust.method = "BH", exact=F)
#A-Line
kruskal.test(Biomass_per_Area ~ Event, data = subset(df, Canal=="A"))#Yes
pairwise.wilcox.test(subset(df, Canal=="A")$Biomass_per_Area, subset(df, Canal=="A")$Event, p.adjust.method = "BH", exact=F)
#UL
kruskal.test(Biomass_per_Area ~ Event, data = subset(df, Canal=="UL"))#Yes
pairwise.wilcox.test(subset(df, Canal=="UL")$Biomass_per_Area, subset(df, Canal=="UL")$Event, p.adjust.method = "BH", exact=F)
#DL
kruskal.test(Biomass_per_Area ~ Event, data = subset(df, Canal=="DL"))#Yes
pairwise.wilcox.test(subset(df, Canal=="DL")$Biomass_per_Area, subset(df, Canal=="DL")$Event, p.adjust.method = "BH", exact=F)

## Site variation
#All canals
kruskal.test(Biomass_per_Area ~ Canal, data = df)#Yes
pairwise.wilcox.test(df$Biomass_per_Area, df$Canal, p.adjust.method = "BH", exact=F)
#Event 1
kruskal.test(Biomass_per_Area ~ Canal, data = subset(df, Event=="1"))#Yes
pairwise.wilcox.test(subset(df, Event=="1")$Biomass_per_Area, subset(df, Event=="1")$Canal, p.adjust.method = "BH", exact=F)
#Event 2
kruskal.test(Biomass_per_Area ~ Canal, data = subset(df, Event=="2"))#Yes
pairwise.wilcox.test(subset(df, Event=="2")$Biomass_per_Area, subset(df, Event=="2")$Canal, p.adjust.method = "BH", exact=F)
#Event 3
kruskal.test(Biomass_per_Area ~ Canal, data = subset(df, Event=="3"))#Yes
pairwise.wilcox.test(subset(df, Event=="3")$Biomass_per_Area, subset(df, Event=="3")$Canal, p.adjust.method = "BH", exact=F)


##### Macrophyte Diversity #####

## Seasonal variation
#All canals
kruskal.test(SDI ~ Event, data = df)#No
#A-Line
kruskal.test(SDI ~ Event, data = subset(df, Canal=="A"))#No
#UL
kruskal.test(SDI ~ Event, data = subset(df, Canal=="UL"))#Yes
#DL
kruskal.test(SDI ~ Event, data = subset(df, Canal=="DL"))#Yes

##Site variation
#All canals
kruskal.test(SDI ~ Canal, data = df)#Yes
pairwise.wilcox.test(df$SDI, df$Canal, p.adjust.method = "BH", exact=F)
#Event 1
kruskal.test(SDI ~ Canal, data = subset(df, Event=="1"))#Yes
pairwise.wilcox.test(subset(df, Event=="1")$SDI, subset(df, Event=="1")$Canal, p.adjust.method = "BH", exact=F)
#Event 2
kruskal.test(SDI ~ Canal, data = subset(df, Event=="2"))#Yes
pairwise.wilcox.test(subset(df, Event=="2")$SDI, subset(df, Event=="2")$Canal, p.adjust.method = "BH", exact=F)
#Event 3
kruskal.test(SDI ~ Canal, data = subset(df, Event=="3"))#Yes
pairwise.wilcox.test(subset(df, Event=="3")$SDI, subset(df, Event=="3")$Canal, p.adjust.method = "BH", exact=F)


##### Correlation between macrophyte density and diversity #####
cor.test(df$Biomass_per_Area, df$SDI, use = "complete.obs", method = "kendall", exact=F)


##### Within and among site variability in macrophyte density and diversity #####
##Biomass
within_variance <- df %>% group_by(Canal, Event) %>%
  summarise(
    cov=sd(Biomass_per_Area)/mean(Biomass_per_Area)
  )
range(within_variance$cov, na.rm=TRUE)

dens_aves <- df %>% group_by(Canal, Event) %>%
  summarise(
    mean_Biomass_per_Area=mean(Biomass_per_Area, na.rm=T)
  )

among_variance <- dens_aves %>% group_by(Event) %>%
  summarise(
    cov=sd(mean_Biomass_per_Area)/mean(mean_Biomass_per_Area)
  )

sd(dens_aves$mean_Biomass_per_Area)/mean(dens_aves$mean_Biomass_per_Area)

##Diversity
SDI_within_variance <- df %>% group_by(Canal, Event) %>%
  summarise(
    cov=sd(SDI, na.rm = T)/mean(SDI, na.rm=T)
  )
range(SDI_within_variance$cov, na.rm=TRUE)

SDIaves <- df %>% group_by(Canal, Event) %>%
  summarise(
    meansdi=mean(SDI, na.rm=T)
  )

SDI_among_variance <- SDIaves %>% group_by(Event) %>%
  summarise(
    cov=sd(meansdi)/mean(meansdi)
  )

sd(SDIaves$meansdi)/mean(SDIaves$meansdi)


##### Curly Leaf Pondweed #####
#Visualize CLPW presence
ggplot(df, aes(x=Event,y=Curly.Leaf.Pondweed, col=Canal))+geom_point()+
  scale_color_manual(breaks = c("UL", "DL", "A"),
                     values=c("#F8766D", "#00BA38", "#83b0fc"))+
  labs(x="Event", y="CLPW bpa")
##Seasonal variation
kruskal.test(Curly.Leaf.Pondweed ~ Event, data = df)#No
##Site variation
kruskal.test(Curly.Leaf.Pondweed ~ Canal, data = df)#No


##### Elodea #####
#Visualize Elodea presence
ggplot(df, aes(x=Event,y=Elodea, col=Canal))+geom_point()+
  scale_color_manual(breaks = c("UL", "DL", "A"),
                     values=c("#F8766D", "#00BA38", "#83b0fc"))+
  labs(x="Event", y="Elodea bpa")
##Seasonal variation
kruskal.test(Elodea ~ Event, data = df)#Yes
##Site variation
kruskal.test(Elodea ~ Canal, data = df)#Yes


##### Filamentous Algae #####
#Visualize Fil Algae presence
ggplot(df, aes(x=Event,y=Filamentous.Algae, col=Canal))+geom_point()+
  scale_color_manual(breaks = c("UL", "DL", "A"),
                     values=c("#F8766D", "#00BA38", "#83b0fc"))+
  labs(x="Event", y="Fil Algae bpa")
##Seasonal variation
kruskal.test(Filamentous.Algae ~ Event, data = df)#No
##Site variation
kruskal.test(Filamentous.Algae ~ Canal, data = df)#Yes


##### Nitella #####
#Visualize Nitella presence
ggplot(df, aes(x=Event,y=Nitella, col=Canal))+geom_point()+
  scale_color_manual(breaks = c("UL", "DL", "A"),
                     values=c("#F8766D", "#00BA38", "#83b0fc"))+
  labs(x="Event", y="Nitella bpa")
##Seasonal variation
kruskal.test(Nitella ~ Event, data = df)#Yes
##Site variation
kruskal.test(Nitella ~ Canal, data = df)#No


##### Milfoil #####
#Visualize Milfoil presence
ggplot(df, aes(x=Event,y=Milfoil, col=Canal))+geom_point()+
  scale_color_manual(breaks = c("UL", "DL", "A"),
                     values=c("#F8766D", "#00BA38", "#83b0fc"))+
  labs(x="Event", y="Milfoil bpa")
##Seasonal variation
kruskal.test(Milfoil ~ Event, data = df)#Yes
##Site variation
kruskal.test(Milfoil ~ Canal, data = df)#No


##### TSS #####
## Seasonal variation
kruskal.test(TSS.mgmL ~ Event, data = df)#Yes
##Site variation
kruskal.test(TSS.mgmL ~ Canal, data = df)#Yes


##### Surface light #####
## Seasonal variation
kruskal.test(PAR.30da ~ Event, data = df)#Yes
##Site variation
kruskal.test(PAR.30da ~ Canal, data = df)#Yes


##### Specific conductivity #####
#Visualize specific conductivity
ggplot(df, aes(x=Event,y=SpC.uS.cm., col=Canal))+geom_point()+
  scale_color_manual(breaks = c("UL", "DL", "A"),
                     values=c("#F8766D", "#00BA38", "#83b0fc"))+
  labs(x="Event", y="SpC.uS.cm. bpa")
## Seasonal variation
kruskal.test(SpC.uS.cm. ~ Event, data = df)#Yes
##Site variation
kruskal.test(SpC.uS.cm. ~ Canal, data = df)#No


##### PW TDC #####
#Visualize PW TDC
ggplot(df, aes(x=Event,y=TDC.mg.L.PW, col=Canal))+geom_point()+
  scale_color_manual(breaks = c("UL", "DL", "A"),
                     values=c("#F8766D", "#00BA38", "#83b0fc"))+
  labs(x="Event", y="TDC.mg.L.PW bpa")
## Seasonal variation
kruskal.test(TDC.mg.L.PW ~ Event, data = df)#Yes
##Site variation
kruskal.test(TDC.mg.L.PW ~ Canal, data = df)#Yes


##### PW TDN #####
#Visualize PW TDN
ggplot(df, aes(x=Event,y=TDN.ug.L.PW, col=Canal))+geom_point()+
  scale_color_manual(breaks = c("UL", "DL", "A"),
                     values=c("#F8766D", "#00BA38", "#83b0fc"))+
  labs(x="Event", y="TDN.ug.L.PW bpa")
## Seasonal variation
kruskal.test(TDN.ug.L.PW ~ Event, data = df)#Yes
##Site variation
kruskal.test(TDN.ug.L.PW ~ Canal, data = df)#Yes


##### SW NH4 #####
#Visualize SW NH4
ggplot(df, aes(x=Event,y=Ammonium.mg.L.SW, col=Canal))+geom_point()+
  scale_color_manual(breaks = c("UL", "DL", "A"),
                     values=c("#F8766D", "#00BA38", "#83b0fc"))+
  labs(x="Event", y="Ammonium.mg.L.SW bpa")
## Seasonal variation
kruskal.test(Ammonium.mg.L.SW ~ Event, data = df)#Yes
##Site variation
kruskal.test(Ammonium.mg.L.SW ~ Canal, data = df)#Yes


##### SW Br #####
#Visualize SW Br
ggplot(df, aes(x=Event,y=Bromide.ppb.SW, col=Canal))+geom_point()+
  scale_color_manual(breaks = c("UL", "DL", "A"),
                     values=c("#F8766D", "#00BA38", "#83b0fc"))+
  labs(x="Event", y="Bromide.ppb.SW bpa")
## Seasonal variation
kruskal.test(Bromide.ppb.SW ~ Event, data = df)#Yes
##Site variation
kruskal.test(Bromide.ppb.SW ~ Canal, data = df)#No


##### SW NO3 #####
#Visualize SW NO3
ggplot(df, aes(x=Event,y=Nitrate.ppb.SW, col=Canal))+geom_point()+
  scale_color_manual(breaks = c("UL", "DL", "A"),
                     values=c("#F8766D", "#00BA38", "#83b0fc"))+
  labs(x="Event", y="Nitrate.ppb.SW bpa")
## Seasonal variation
kruskal.test(Nitrate.ppb.SW ~ Event, data = df)#Yes
##Site variation
kruskal.test(Nitrate.ppb.SW ~ Canal, data = df)#Yes


##### SW DOC #####
#Visualize SW DOC
ggplot(df, aes(x=Event,y=DOC.mg.L.SW, col=Canal))+geom_point()+
  scale_color_manual(breaks = c("UL", "DL", "A"),
                     values=c("#F8766D", "#00BA38", "#83b0fc"))+
  labs(x="Event", y="DOC.mg.L.SW bpa")
## Seasonal variation
kruskal.test(DOC.mg.L.SW ~ Event, data = df)#Yes
##Site variation
kruskal.test(DOC.mg.L.SW ~ Canal, data = df)#Yes


##### SW TDN #####
#Visualize SW TDN
ggplot(df, aes(x=Event,y=TDN.ug.L.SW, col=Canal))+geom_point()+
  scale_color_manual(breaks = c("UL", "DL", "A"),
                     values=c("#F8766D", "#00BA38", "#83b0fc"))+
  labs(x="Event", y="TDN.ug.L.SW bpa")
## Seasonal variation
kruskal.test(TDN.ug.L.SW ~ Event, data = df)#Yes
##Site variation
kruskal.test(TDN.ug.L.SW ~ Canal, data = df)#Yes


##### Flow #####
#Visualize Flow
ggplot(df, aes(x=Event,y=Flow.cms.30da, col=Canal))+geom_point()+
  scale_color_manual(breaks = c("UL", "DL", "A"),
                     values=c("#F8766D", "#00BA38", "#83b0fc"))+
  labs(x="Event", y="Flow.cms.30da")
## Seasonal variation
kruskal.test(Flow.cms.30da ~ Event, data = df)#Yes
##Site variation
kruskal.test(Flow.cms.30da ~ Canal, data = df)#Yes


##### Sed % OM #####
#Visualize Sed % OM
ggplot(df, aes(x=Event,y=Sed.PercentOM, col=Canal))+geom_point()+
  scale_color_manual(breaks = c("UL", "DL", "A"),
                     values=c("#F8766D", "#00BA38", "#83b0fc"))+
  labs(x="Event", y="Sed % OM")
## Seasonal variation
kruskal.test(Sed.PercentOM ~ Event, data = df)#No
##Site variation
kruskal.test(Sed.PercentOM ~ Canal, data = df)#Yes
pairwise.wilcox.test(df$Sed.PercentOM, df$Canal, p.adjust.method = "BH", exact=F)


##### Surface water pH #####
#Visualize pH
ggplot(df, aes(x=Event,y=pH, col=Canal))+geom_point()+
  scale_color_manual(breaks = c("UL", "DL", "A"),
                     values=c("#F8766D", "#00BA38", "#83b0fc"))+
  labs(x="Event", y="pH bpa")
## Seasonal variation
kruskal.test(pH ~ Event, data = df)#Yes
##Site variation
kruskal.test(pH ~ Canal, data = df)#Yes


##### Temperature ####
temp<-read.csv("Data_Final/WaterTemp_DailyAverages.csv")#Read in daily temp data
#Visualize temp daily averages
ggplot(temp, aes(x=Date,y=approx, col=Canal))+geom_point()+
  scale_color_manual(breaks = c("UL", "DL", "A"),
                     values=c("#F8766D", "#00BA38", "#83b0fc"))+
  labs(x="Date", y="Average Daily Temperature (°C)")
#Visualize temp 30 day averages
ggplot(df, aes(x=Event,y=Temp.30da, col=Canal))+geom_point()+
  scale_color_manual(breaks = c("UL", "DL", "A"),
                     values=c("#F8766D", "#00BA38", "#83b0fc"))+
  labs(x="Event", y="Temp.30da bpa")
## Seasonal variation
kruskal.test(Temp.30da ~ Event, data = df)#Yes
##Site variation
kruskal.test(Temp.30da ~ Canal, data = df)#No


##### PW NH4 #####
#Visualize pH
ggplot(df, aes(x=Event,y=Ammonium.mg.L.PW, col=Canal))+geom_point()+
  scale_color_manual(breaks = c("UL", "DL", "A"),
                     values=c("#F8766D", "#00BA38", "#83b0fc"))+
  labs(x="Event", y="Ammonium.mg.L.PW bpa")
## Seasonal variation
kruskal.test(Ammonium.mg.L.PW ~ Event, data = df)#Yes
##Site variation
kruskal.test(Ammonium.mg.L.PW ~ Canal, data = df)#Yes


##### PW Fl #####
#Visualize pH
ggplot(df, aes(x=Event,y=Fluoride.ppb.PW, col=Canal))+geom_point()+
  scale_color_manual(breaks = c("UL", "DL", "A"),
                     values=c("#F8766D", "#00BA38", "#83b0fc"))+
  labs(x="Event", y="Fluoride.ppb.PW bpa")
## Seasonal variation
kruskal.test(Fluoride.ppb.PW ~ Event, data = df)#Yes
##Site variation
kruskal.test(Fluoride.ppb.PW ~ Canal, data = df)#Yes


##### PW DOC #####
#Visualize pH
ggplot(df, aes(x=Event,y=DOC.mg.L.PW, col=Canal))+geom_point()+
  scale_color_manual(breaks = c("UL", "DL", "A"),
                     values=c("#F8766D", "#00BA38", "#83b0fc"))+
  labs(x="Event", y="DOC.mg.L.PW bpa")
## Seasonal variation
kruskal.test(DOC.mg.L.PW ~ Event, data = df)#Yes
##Site variation
kruskal.test(DOC.mg.L.PW ~ Canal, data = df)#Yes


##### PW TDC #####
#Visualize pH
ggplot(df, aes(x=Event,y=TDC.mg.L.PW, col=Canal))+geom_point()+
  scale_color_manual(breaks = c("UL", "DL", "A"),
                     values=c("#F8766D", "#00BA38", "#83b0fc"))+
  labs(x="Event", y="TDC.mg.L.PW bpa")
## Seasonal variation
kruskal.test(TDC.mg.L.PW ~ Event, data = df)#Yes
##Site variation
kruskal.test(TDC.mg.L.PW ~ Canal, data = df)#Yes


##### SW DOC #####
#Visualize pH
ggplot(df, aes(x=Event,y=DOC.mg.L.SW, col=Canal))+geom_point()+
  scale_color_manual(breaks = c("UL", "DL", "A"),
                     values=c("#F8766D", "#00BA38", "#83b0fc"))+
  labs(x="Event", y="DOC.mg.L.SW bpa")
## Seasonal variation
kruskal.test(DOC.mg.L.SW ~ Event, data = df)#Yes
##Site variation
kruskal.test(DOC.mg.L.SW ~ Canal, data = df)#Yes


##### SW TDC #####
#Visualize pH
ggplot(df, aes(x=Event,y=TDC.mg.L.SW, col=Canal))+geom_point()+
  scale_color_manual(breaks = c("UL", "DL", "A"),
                     values=c("#F8766D", "#00BA38", "#83b0fc"))+
  labs(x="Event", y="TDC.mg.L.SW bpa")
## Seasonal variation
kruskal.test(TDC.mg.L.SW ~ Event, data = df)#Yes
##Site variation
kruskal.test(TDC.mg.L.SW ~ Canal, data = df)#Yes

