#Seasonal variation, plots, and biomass models for compartment metabolism values
#Meredith Brehob
#5/10/2021
#This code will run kruskal-wallis tests, plot, and perform glms on biomass effects for compartment metabolism data.

library(DHARMa)
library(sjPlot)
library(ggplot2)
library(tidyverse)
library(ggpubr)
library(cowplot)

#Read in data
df<-read.csv("Data_Final/Environmental_and_CompartmentMetabolism_AllObservations.csv")
#Make Canal and Event factors
df$Event<-as.factor(df$Event)
df$Canal<-as.factor(df$Canal)


##### Seasonal variation GPP - Macrophyte compartment #####
#All canals
kruskal.test(GPP.mg.per.g.per.hr ~ Event, data = df)#Yes
pairwise.wilcox.test(df$GPP.mg.per.g.per.hr, df$Event, p.adjust.method = "BH", exact=F)#All<0.05
#A-Line
kruskal.test(GPP.mg.per.g.per.hr ~ Event, data = subset(df, Canal=="A"))#NO
#UL
kruskal.test(GPP.mg.per.g.per.hr ~ Event, data = subset(df, Canal=="UL"))#Yes
pairwise.wilcox.test(subset(df, Canal=="UL")$GPP.mg.per.g.per.hr, subset(df, Canal=="UL")$Event, p.adjust.method = "BH", exact=F)#Events 2 and 3 not different at UL
#DL
kruskal.test(GPP.mg.per.g.per.hr ~ Event, data = subset(df, Canal=="DL"))#Yes
pairwise.wilcox.test(subset(df, Canal=="DL")$GPP.mg.per.g.per.hr, subset(df, Canal=="DL")$Event, p.adjust.method = "BH", exact=F)#Events 2 and 3 NOT different at DL


##### Seasonal variation ER - Macrophyte compartment #####
#All canals
kruskal.test(CR.mg.per.g.per.hr ~ Event, data = subset(df, Substrate=="Plant"))#p<0.05
pairwise.wilcox.test(subset(df, Substrate=="Plant")$CR.mg.per.g.per.hr, subset(df, Substrate=="Plant")$Event, p.adjust.method = "BH", exact=F)#ONLY Events 1 and 3 are different (p<0.05)
#A-Line
kruskal.test(CR.mg.per.g.per.hr ~ Event, data = subset(df, Canal=="A" & Substrate=="Plant"))#Yes
pairwise.wilcox.test(subset(df, Canal=="A" & Substrate=="Plant")$CR.mg.per.g.per.hr, subset(df, Canal=="A" & Substrate=="Plant")$Event, p.adjust.method = "BH", exact=F)#No data for event 3 - event 1 and 2 different
#UL
kruskal.test(CR.mg.per.g.per.hr ~ Event, data = subset(df, Canal=="UL" & Substrate=="Plant"))#Yes
pairwise.wilcox.test(subset(df, Canal=="UL" & Substrate=="Plant")$CR.mg.per.g.per.hr, subset(df, Canal=="UL" & Substrate=="Plant")$Event, p.adjust.method = "BH", exact=F)#Events 1 and 3 are NOT different
#DL
kruskal.test(CR.mg.per.g.per.hr ~ Event, data = subset(df, Canal=="DL" & Substrate=="Plant"))#Yes
pairwise.wilcox.test(subset(df, Canal=="DL" & Substrate=="Plant")$CR.mg.per.g.per.hr, subset(df, Canal=="DL" & Substrate=="Plant")$Event, p.adjust.method = "BH", exact=F)#ONLY Events 1 and 2 are different


##### Seasonal variation ER - Sediment compartment #####
#All canals
kruskal.test(CR.mg.per.g.per.hr ~ Event, data = subset(df, Substrate=="Sed"))#Yes
pairwise.wilcox.test(subset(df, Substrate=="Sed")$CR.mg.per.g.per.hr, subset(df, Substrate=="Sed")$Event, p.adjust.method = "BH", exact=F)#ALL events different
#A-Line
kruskal.test(CR.mg.per.g.per.hr ~ Event, data = subset(df, Canal=="A" & Substrate=="Sed"))#Yes
pairwise.wilcox.test(subset(df, Canal=="A" & Substrate=="Sed")$CR.mg.per.g.per.hr, subset(df, Canal=="A" & Substrate=="Sed")$Event, p.adjust.method = "BH", exact=F)#ALL events different
#UL
kruskal.test(CR.mg.per.g.per.hr ~ Event, data = subset(df, Canal=="UL" & Substrate=="Sed"))#NO
#DL
kruskal.test(CR.mg.per.g.per.hr ~ Event, data = subset(df, Canal=="DL" & Substrate=="Sed"))#Yes
pairwise.wilcox.test(subset(df, Canal=="DL" & Substrate=="Sed")$CR.mg.per.g.per.hr, subset(df, Canal=="DL" & Substrate=="Sed")$Event, p.adjust.method = "BH", exact=F)#Events 2 and 3 NOT different


##### Figure showing GPP and ER rates for each event #####
##Summarizing data for plotting purposes
plotdata<-df %>%
  group_by(Event,Canal,Date, Substrate)%>%
  summarise(
    GPPmean = mean(GPP.mg.per.g.per.hr, na.rm=T),
    GPPsd = sd(GPP.mg.per.g.per.hr, na.rm=T),
    CRmean = mean(CR.mg.per.g.per.hr, na.rm=T),
    CRsd = sd(CR.mg.per.g.per.hr, na.rm=T))

##Put zeros into A event 3 data so that it will plot properly
plotdata[20,4]<-"Plant"
plotdata[20,5]<-0
plotdata[20,7]<-0

##Splitting up plot data into plant and sed compartments
pplotdata<-subset(plotdata, Substrate=="Plant")
p.fill.order <- factor(pplotdata$Canal, levels = c('UL', 'DL', 'A'))#creating fill order so that it is in correct sampling order

##Individual GPP and ER plots for each event/canal
GGPplot<-ggplot(pplotdata, aes(x = Event, y = GPPmean, fill = p.fill.order)) + 
  geom_bar(position = "dodge", stat = 'identity') +
  labs(y=expression(paste("GPP (mg/g/hr)")))+
  theme_bw()+
  theme(legend.position = "none", 
        panel.grid.minor = element_blank(),
        panel.grid.major.x = element_blank(),
        axis.text = element_text(size=10),
        plot.title=element_text(size=11, hjust=0.5),
        axis.title.x = element_blank(),
        plot.margin = unit(c(7, 7, 0, 7), "pt"))+ 
  coord_cartesian(ylim = c(0, 5))+
  scale_fill_manual(values = c("UL" = "#FA492D", "DL" = "#5F98FA", "A" = "#85AD1F"))+ #add colors that I want
  geom_errorbar(aes(ymin=GPPmean-GPPsd, ymax=GPPmean+GPPsd), width=.2,position=position_dodge(.9),stat="identity")#add error bars

CRPplot<-ggplot(pplotdata, aes(x = Event, y = -CRmean, fill = p.fill.order)) + 
  geom_bar(position = "dodge", stat = 'identity') +
  labs(y=expression(paste("ER (mg/g/hr)")))+
  theme_bw()+
  scale_x_discrete(position="top")+
  ylim(-5,0)+
  theme(legend.position = "none", 
        panel.grid.minor = element_blank(),
        panel.grid.major.x = element_blank(),
        axis.text = element_text(size=10),
        plot.title=element_text(size=11, hjust=0.5))+
  scale_fill_manual(values = c("UL" = "#FA492D", "DL" = "#5F98FA", "A" = "#85AD1F"))+ #add colors that I want
  geom_errorbar(aes(ymin=-CRmean-CRsd, ymax=-CRmean+CRsd), width=.2,position=position_dodge(.9),stat="identity")#add error bars

sedplotdata<-subset(plotdata, Substrate=="Sed")
s.fill.order <- factor(sedplotdata$Canal, levels = c('UL', 'DL', 'A'))#creating fill order so that it is in correct sampling order

CRSplot<-ggplot(sedplotdata, aes(x = Event, y = -CRmean, fill = s.fill.order)) + 
  geom_bar(position = "dodge", stat = 'identity') +
  labs(y=expression(paste("ER (mg/g/hr)")))+
  theme_bw()+
  scale_x_discrete(position="top")+
  ylim(-5,0)+
  theme(panel.grid.minor = element_blank(),
        panel.grid.major.x = element_blank(),
        axis.text = element_text(size=10),
        plot.title=element_text(size=11, hjust=0.5),
        legend.text =  element_text(size=10))+
  scale_fill_manual(values = c("UL" = "#FA492D", "DL" = "#5F98FA", "A" = "#85AD1F"), name="Canal")+ #add colors that I want
  geom_errorbar(aes(ymin=-CRmean-CRsd, ymax=-CRmean+CRsd), width=.2,position=position_dodge(.9),stat="identity")#add error bars

## Combine plots
plantplot <- cowplot::plot_grid(GGPplot, CRPplot, ncol=1, align = "v")
plantplot <- gridExtra::grid.arrange(plantplot, bottom="Macrophyte Compartments")
CRSplotnoleg <- CRSplot + theme(legend.position = "none")#Make graph 2 without it's legend
le1 <- get_legend(CRSplot)#Create an object of the legend from graph 2
sedplot <- cowplot::plot_grid(le1, CRSplotnoleg, ncol=1, rel_heights = c(2,2))
sedplot <- gridExtra::grid.arrange(sedplot, bottom="Sediment Compartments")
cowplot::plot_grid(plantplot, sedplot, align ="h")#, ncol=2, align="v", rel_heights = c(3,2), labels="AUTO", scale=0.95)#Plot just the two graphs (no legend) so that I can align the y axes


## Different configuration of plots
GGPplot<-ggplot(pplotdata, aes(x = Event, y = GPPmean, fill = p.fill.order)) + 
  geom_bar(position = "dodge", stat = 'identity') +
  labs(y=expression(paste("Macrophyte GPP (mg ", O[2], "/g/hr)")))+
  theme_bw()+
  theme(legend.position = "none", 
        panel.grid.minor = element_blank(),
        panel.grid.major.x = element_blank(),
        axis.text = element_text(size=10),
        plot.title=element_text(size=11, hjust=0.5))+ 
  coord_cartesian(ylim = c(0, 5))+
  scale_fill_manual(values = c("UL" = "#FA492D", "DL" = "#5F98FA", "A" = "#85AD1F"))+ #add colors that I want
  geom_errorbar(aes(ymin=GPPmean-GPPsd, ymax=GPPmean+GPPsd), width=.2,position=position_dodge(.9),stat="identity")#add error bars

CRPplot<-ggplot(pplotdata, aes(x = Event, y = CRmean, fill = p.fill.order)) + 
  geom_bar(position = "dodge", stat = 'identity') +
  labs(y=expression(paste("abs(Macrophyte ER) (mg ", O[2], "/g/hr)")))+
  theme_bw()+
  ylim(0,5)+
  theme(legend.position = "none", 
        panel.grid.minor = element_blank(),
        panel.grid.major.x = element_blank(),
        axis.text = element_text(size=10),
        plot.title=element_text(size=11, hjust=0.5))+
  scale_fill_manual(values = c("UL" = "#FA492D", "DL" = "#5F98FA", "A" = "#85AD1F"))+ #add colors that I want
  geom_errorbar(aes(ymin=CRmean-CRsd, ymax=CRmean+CRsd), width=.2,position=position_dodge(.9),stat="identity")#add error bars

sedplotdata<-subset(plotdata, Substrate=="Sed")
s.fill.order <- factor(sedplotdata$Canal, levels = c('UL', 'DL', 'A'))#creating fill order so that it is in correct sampling order

CRSplot<-ggplot(sedplotdata, aes(x = Event, y = CRmean, fill = s.fill.order)) + 
  geom_bar(position = "dodge", stat = 'identity') +
  labs(y=expression(paste("abs(Sediment ER) (mg ", O[2], "/g/hr)")))+
  theme_bw()+
  ylim(0,5)+
  theme(panel.grid.minor = element_blank(),
        panel.grid.major.x = element_blank(),
        axis.text = element_text(size=10),
        plot.title=element_text(size=11, hjust=0.5),
        legend.text =  element_text(size=10))+
  scale_fill_manual(values = c("UL" = "#FA492D", "DL" = "#5F98FA", "A" = "#85AD1F"), name="Canal")+ #add colors that I want
  geom_errorbar(aes(ymin=CRmean-CRsd, ymax=CRmean+CRsd), width=.2,position=position_dodge(.9),stat="identity")#add error bars

## Combine plots
CRSplotnoleg <- CRSplot + theme(legend.position = "none")#Make graph 2 without it's legend
le1 <- get_legend(CRSplot)#Create an object of the legend from graph 2
cowplot::plot_grid(GGPplot, CRPplot, CRSplotnoleg, le1, nrow=1, align = "h", rel_widths = c(1,1,1,0.3))


##### Biomass controls on compartment metab #####
#Make new variable with small value added to remove zeros
df$GPP0.0001<-df$GPP.mg.per.g.per.hr+0.0001
df$CR0.0001<-df$CR.mg.per.g.per.hr+0.0001

##Macrophyte compartment GPP vs macrophyte density
##Among transects
#W/o event or canal as effects
summary(glm(GPP0.0001~Biomass_per_Area-1,data=df,family=Gamma(link="log")))
#W/ event and canal as fixed effects (had to remove A-Line data or model wouldn't converge)
summary(glm(GPP0.0001~Event+Canal+Biomass_per_Area-1,data=subset(df, Canal != "A"),family=Gamma(link="log")))

##Macrophyte compartment ER vs macrophyte density
#W/o event or canal as effects
summary(glm(CR0.0001~Biomass_per_Area-1,data=subset(df, Substrate = "Plant"),family=Gamma(link="log")))
#W/ canal and event as effects
summary(glm(CR0.0001~Canal+Event+Biomass_per_Area-1,data=subset(df, Substrate = "Plant"),family=Gamma(link="log")))

##Sediment compartment ER vs sediment organic matter
#W/o event or canal as effects
summary(glm(CR0.0001~WinklerSedPerOM-1,data=subset(df, Substrate = "Sed"),family=Gamma(link="log")))
#W/ canal and event as effects
summary(glm(CR0.0001~Canal+Event+WinklerSedPerOM-1,data=subset(df, Substrate = "Sed"),family=Gamma(link="log")))
#Plot of raw data
ggplot(data=df, aes(x=WinklerSedPerOM, y=CR0.0001, col=Canal))+
  geom_point()+
  theme_bw()+
  scale_color_manual(values = c("UL" = "#FA492D", "DL" = "#5F98FA", "A" = "#85AD1F"), name="Canal")+
  labs(y=expression(paste("ER (mg ", O[2], "/g/hr)")), x=expression(paste("Percent (%) Organic Matter")))+
  theme(panel.grid.minor = element_blank())
